/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.inspectors;

import java.lang.annotation.Annotation;
import java.util.ArrayList;

/**
 * Provides an inspector for an annotation.
 * 
 * @author Rainer Schwarze
 */
public class AnnotationInspector extends AbstractInspector<Annotation> {

	/**
	 * Creates an instance with the given label and annotation instance.
	 * 
	 * @param label	The label of the inspector.
	 * @param item	The annotation to inspect.
	 */
	public AnnotationInspector(String label, Annotation item) {
		super(label, item, TYPE.ANNOTATION);
		setShortInfo(item.annotationType().getSimpleName());
		setDetailedInfo("annotation type : " + item.annotationType().getCanonicalName());
		setExpandable(true);
	}

	@Override
	public synchronized void expand(ArrayList<IInspector<?>> list) {
		expand(getItem(), list);
	}

	/**
	 * Expands the information for the annotation item.
	 * 
	 * @param <T> 
	 * @param item
	 * @param list
	 */
	static public <T extends Annotation> void expand(T item, ArrayList<IInspector<?>> list) {
		list.add(new ClassInspector("annotation type", item.annotationType()));
		list.add(new SimplePropertyInspector("toString", item.toString()));
	}
}
