/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.inspectors;

import java.lang.reflect.Field;
import java.util.ArrayList;

/**
 * Provides an inspector for Fields.
 * 
 * @author Rainer Schwarze
 */
public class FieldInspector extends AbstractInspector<Field> {

	/**
	 * Creates an instance with the given parameters.
	 * 
	 * @param label the label of this inspector.
	 * @param item	The Field to inspect.
	 */
	public FieldInspector(String label, Field item) {
		super(label, item, TYPE.FIELD);
		setShortInfo(item.getName() + " (" + item.getType().getSimpleName() + ")");
		addDetail("name", item.getName());
		addDetail("declared type", item.getType().getSimpleName());
		addDetail("declared type (canonical)", item.getType().getCanonicalName());
		setExpandable(true);
	}

	@Override
	public synchronized void expand(ArrayList<IInspector<?>> list) {
		Field f = getItem();

		Field item = getItem();
		Helper.expandMember(item, list);
		Helper.expandAnnotatedElement(item, list);

		list.add(new ClassInspector("type (declared)", f.getType()));

		list.add(new SimplePropertyInspector("toGenericString", item.toGenericString()));
		list.add(new SimplePropertyInspector("toString", item.toString()));
	}
}
