/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.inspectors;

import java.util.ArrayList;
import java.util.List;

/**
 * Provides an inspector used for grouping other inspectors.
 * This inspector does not correspond to a class or object in the 
 * "reflection tree", it only servers as a semantic grouping.
 * 
 * @author Rainer Schwarze
 */
public class GroupInspector extends AbstractInspector<List<IInspector<?>>> {

	/**
	 * Creates an instance with the given parameters.
	 * 
	 * @param label	The label for the inspector.
	 * @param item	The list of inspectors grouped for inspection.
	 * @param type	The type of this group (usually UNKNOWN).
	 * @param shortInfo A short information like the name of the item within which
	 * 					the grouping is done.
	 */
	public GroupInspector(String label, List<IInspector<?>> item, TYPE type, String shortInfo) {
		super(label, item, type);
		setShortInfo(shortInfo);
	}

	/**
	 * @param list
	 * @see de.admadic.papers.reflection.inspectors.AbstractInspector#expand(java.util.ArrayList)
	 */
	@Override
	public void expand(ArrayList<IInspector<?>> list) {
		list.addAll(getItem());
	}

	/**
	 * @return	Returns true, if the group list contains items.
	 * @see de.admadic.papers.reflection.inspectors.AbstractInspector#isExpandable()
	 */
	@Override
	public boolean isExpandable() {
		return getItem().size()!=0;
	}
}
