/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.inspectors;

import java.util.ArrayList;

/**
 * Provides an inspector for a package.
 * 
 * @author Rainer Schwarze
 */
public class PackageInspector extends AbstractInspector<Package> {

	/**
	 * Creates an instance with the given parameters.
	 * The parameter <code>item</code> may be <code>null</code>.
	 * 
	 * @param label	The label of the inspector.
	 * @param item	The Package to inspect.
	 */
	public PackageInspector(String label, Package item) {
		super(label, item, TYPE.PACKAGE);
		if (item!=null) {
			setShortInfo(item.getName());
			setExpandable(true);
		} else {
			setShortInfo("<null>");
		}
	}

	/**
	 * @param list
	 * @see de.admadic.papers.reflection.inspectors.AbstractInspector#expand(ArrayList)
	 */
	@Override
	public synchronized void expand(ArrayList<IInspector<?>> list) {
		Package item = getItem();
		list.add(new SimplePropertyInspector("name", item.getName()));
		list.add(new SimplePropertyInspector("specification title", item.getSpecificationTitle()));
		list.add(new SimplePropertyInspector("specification vendor", item.getSpecificationVendor()));
		list.add(new SimplePropertyInspector("specification version", item.getSpecificationVersion()));
		list.add(new SimplePropertyInspector("implementation title", item.getImplementationTitle()));
		list.add(new SimplePropertyInspector("implementation vendor", item.getImplementationVendor()));
		list.add(new SimplePropertyInspector("implementation version", item.getImplementationVersion()));
		Helper.expandAnnotatedElement(item, list);
	}
}
