/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.inspectors;

import java.util.ArrayList;

/**
 * Provides an inspector which shall be in the root node of the
 * tree structure. A RootItemInspector can hold an Object or a Class
 * and will expand from there.
 * 
 * Currently Object inspection is not supported. If an Object has been
 * passed, its Class is retrieved and a ClassInspector for that class is
 * added to the tree.
 * 
 * @author Rainer Schwarze
 */
public class RootItemInspector extends AbstractInspector<Object> {
	/**
	 * Creates an instance with the given parameters.
	 * 
	 * @param item
	 */
	public RootItemInspector(Object item) {
		super("[root]", item, TYPE.UNKNOWN);
		setExpandable(true);
		if (item instanceof Class) {
			Class classItem = (Class)item;
			setShortInfo(classItem.getSimpleName());
			setDetailedInfo("class : " + classItem.getCanonicalName());
		} else {
			setShortInfo(item.getClass().getSimpleName());
			setDetailedInfo(
					"Type : " + item.getClass().getCanonicalName() + "\n" + 
					"An object is being inspected");
		}
	}

	/**
	 * @param list
	 * @see de.admadic.papers.reflection.inspectors.AbstractInspector#expand(ArrayList)
	 */
	@Override
	public synchronized void expand(ArrayList<IInspector<?>> list) {
		Class cls = null;
		Object obj = null;
		if (getItem() instanceof Class) {
			cls = (Class) getItem();
		} else {
			obj = getItem();
			cls = obj.getClass();
		}
		list.add(new ClassInspector("class", cls));
		if (obj!=null) list.add(new ObjectLevelInspector("instance information", obj));
	}
}
