/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.inspectors;

import java.util.ArrayList;

/**
 * Creates an inspector which represents a simple pair of two Strings
 * being the label and the value.
 * The value String is passed in as the "inspected item". The method 
 * getShortInfo is overridden to return the item (if it is non-null).
 * 
 * @author Rainer Schwarze
 */
public class SimplePropertyInspector extends AbstractInspector<String> {

	/**
	 * Creates an instance of the inspector with a label/value pair of
	 * Strings.
	 * 
	 * @param label	The label of the inspector. 
	 * @param item	The value of the inspector.
	 */
	public SimplePropertyInspector(String label, String item) {
		super(label, item, TYPE.PROPERTY);
		setDetailedInfo("(no details - its a simple property)");
	}

	/**
	 * @param list
	 * @see de.admadic.papers.reflection.inspectors.AbstractInspector#expand(ArrayList)
	 */
	@Override
	public synchronized void expand(ArrayList<IInspector<?>> list) {
		// no op
	}

	/**
	 * @return	Returns the short information.
	 * @see de.admadic.papers.reflection.inspectors.AbstractInspector#getShortInfo()
	 */
	@Override
	public String getShortInfo() {
		// FIXME: ok that way?
		String item = getItem();
		return item==null ? "(null)" : item;
	}
}
