/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.inspectors;

/**
 * Provides types for inspectors.
 * Types are currently used to display inspectors in the tree view with 
 * different colors depending on their type.
 * 
 * @author Rainer Schwarze
 */
public enum TYPE {
	/** The type of the inspectors which are temporarily used while an expansion is processed. */
	BUSY,
	/** The type of error inspectors which display error information. */
	ERROR,
	/** The unknown type is the default value for uninitialized type fields. */
	UNKNOWN,
	/** The inspector represents a class. */
	CLASS,
	/** The inspector represents an instance. Note that instance support is not complete. */
	OBJECT,
	/** The inspector represents a field. */
	FIELD,
	/** The inspector represents a method (no constructor). */
	METHOD,
	/** The inspector represents a constructor. */
	CONSTRUCTOR,
	/** The inspector represents a generic type. */
	TYPE,
	/** The inspector represents an annotation. */
	ANNOTATION,
	/** The inspector represents a simple property like in "name = java.lang.Class". */
	PROPERTY,
	/** The inspector represents a package. */
	PACKAGE,
}