/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.inspectors;

import java.lang.reflect.Type;
import java.util.ArrayList;

/**
 * This serves as a base class for the inspectors of subclasses of Type.
 * (Note: since the Type interface does not have any methods, the expand() 
 * methods does nothing.)
 * 
 * @author Rainer Schwarze
 * @param <T> 
 */
public class TypeInspector<T extends Type> extends AbstractInspector<T> {

	/**
	 * @param label The label of this inspector.
	 * @param item
	 * @param type 
	 */
	public TypeInspector(String label, T item, TYPE type) {
		super(label, item, type);
		setShortInfo("? extends Type");
	}

	/**
	 * @param list
	 * @see de.admadic.papers.reflection.inspectors.AbstractInspector#expand(ArrayList)
	 */
	@Override
	public synchronized void expand(ArrayList<IInspector<?>> list) {
		// actually there's nothing common to expand for a Type
	}

	/**
	 * @param <T>
	 * @param item
	 * @param list
	 */
	static public <T extends Type> void expand(T item, ArrayList<IInspector<?>> list) {
		// nothing
	}
}
