/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.inspectors;

import java.lang.reflect.GenericDeclaration;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.util.ArrayList;

/**
 * @author Rainer Schwarze
 *
 */
public class TypeVariableInspector extends TypeInspector<TypeVariable<? extends GenericDeclaration>> {

	/**
	 * @param label The label of this inspector.
	 * @param item
	 */
	public TypeVariableInspector(String label, TypeVariable<? extends GenericDeclaration> item) {
		super(label, item, TYPE.TYPE);
		setShortInfo(item.getName());
		addDetail("name", item.getName());
		addDetail("generic declaration", item.getGenericDeclaration().toString());
		addDetail("details", item.toString());
		setExpandable(true);
	}

	/**
	 * @param list
	 * @see de.admadic.papers.reflection.inspectors.TypeInspector#expand(ArrayList)
	 */
	@Override
	public void expand(ArrayList<IInspector<?>> list) {
		super.expand(list);
		TypeVariable<? extends GenericDeclaration> t = getItem();
		list.add(new SimplePropertyInspector(
				"name", t.getName()));
		list.add(new ArrayInspector<Type>(
				"bounds", Util.makeList(t.getBounds())));
		// FIXME: is that ok, or should we link to the actual GenericDeclarationInspector?
//		list.add(new GenericDeclarationInspector(
//				"generic declaration", t.getGenericDeclaration()));
		list.add(Factory.create("generic declaration", t.getGenericDeclaration()));
	}
}
