/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.log;

/**
 * Provides a Logger interface compatible with log4j serving as a facade to
 * apache log4j. The purpose of working through this interface is to decouple 
 * completely from log4j jars.
 * 
 * @author Rainer Schwarze
 */
public interface ILogger {
	// we do not need full blown documentation of methods...

	/**
	 * @param message
	 * @param t
	 */
	public abstract void debug(Object message, Throwable t);

	/**
	 * @param message
	 */
	public abstract void debug(Object message);

	/**
	 * @param message
	 * @param t
	 */
	public abstract void error(Object message, Throwable t);

	/**
	 * @param message
	 */
	public abstract void error(Object message);

	/**
	 * @param message
	 * @param t
	 */
	public abstract void fatal(Object message, Throwable t);

	/**
	 * @param message
	 */
	public abstract void fatal(Object message);

	/**
	 * @param message
	 * @param t
	 */
	public abstract void info(Object message, Throwable t);

	/**
	 * @param message
	 */
	public abstract void info(Object message);

	/**
	 * @return	Returns true, if the debug level is enabled.
	 */
	public abstract boolean isDebugEnabled();

	/**
	 * @return	Returns true, if the info level is enabled.
	 */
	public abstract boolean isInfoEnabled();

	/**
	 * @return	Returns true, if the trace level is enabled.
	 */
	public abstract boolean isTraceEnabled();

	/**
	 * @param message
	 * @param t
	 */
	public abstract void trace(Object message, Throwable t);

	/**
	 * @param message
	 */
	public abstract void trace(Object message);

	/**
	 * @param message
	 * @param t
	 */
	public abstract void warn(Object message, Throwable t);

	/**
	 * @param message
	 */
	public abstract void warn(Object message);

}
