/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.log;

import java.io.File;

import org.apache.log4j.PropertyConfigurator;

/**
 * Provides a project level encapsulation of logging facilities. This logger is 
 * using log4j as a backend.
 * 
 * @author Rainer Schwarze
 */
public class Log4jLogger implements ILogger {
	private Class loggerClass;
	private org.apache.log4j.Logger loggerDelegate;

	/**
	 * Initializes the Logger facilities.
	 */
	public static void initialize() {
		String cfg = "../log4j.properties";
		if (!(new File("../log4j.properties").exists())) {
			if ((new File("./log4j.properties").exists())) {
				cfg = "./log4j.properties";
			}
		}
			
		PropertyConfigurator.configure(cfg);
	}

	/**
	 * Returns a Logger instance for the specified class.
	 * 
	 * @param loggerClass
	 * @return	The Logger instance created for the given class.
	 */
	public static Log4jLogger getLogger(Class loggerClass) {
		return new Log4jLogger(loggerClass);
	}
	
	protected Log4jLogger(Class loggerClass) {
		super();
		this.loggerClass = loggerClass;
		this.loggerDelegate = org.apache.log4j.Logger.getLogger(this.loggerClass);
	}

	/**
	 * @param message
	 * @param t
	 * @see de.admadic.papers.reflection.log.ILogger#debug(java.lang.Object, java.lang.Throwable)
	 */
	public void debug(Object message, Throwable t) {
		loggerDelegate.debug(message, t);
	}

	/**
	 * @param message
	 * @see de.admadic.papers.reflection.log.ILogger#debug(java.lang.Object)
	 */
	public void debug(Object message) {
		loggerDelegate.debug(message);
	}

	/**
	 * @param message
	 * @param t
	 * @see de.admadic.papers.reflection.log.ILogger#error(java.lang.Object, java.lang.Throwable)
	 */
	public void error(Object message, Throwable t) {
		loggerDelegate.error(message, t);
	}

	/**
	 * @param message
	 * @see de.admadic.papers.reflection.log.ILogger#error(java.lang.Object)
	 */
	public void error(Object message) {
		loggerDelegate.error(message);
	}

	/**
	 * @param message
	 * @param t
	 * @see de.admadic.papers.reflection.log.ILogger#fatal(java.lang.Object, java.lang.Throwable)
	 */
	public void fatal(Object message, Throwable t) {
		loggerDelegate.fatal(message, t);
	}

	/**
	 * @param message
	 * @see de.admadic.papers.reflection.log.ILogger#fatal(java.lang.Object)
	 */
	public void fatal(Object message) {
		loggerDelegate.fatal(message);
	}

	/**
	 * @param message
	 * @param t
	 * @see de.admadic.papers.reflection.log.ILogger#info(java.lang.Object, java.lang.Throwable)
	 */
	public void info(Object message, Throwable t) {
		loggerDelegate.info(message, t);
	}

	/**
	 * @param message
	 * @see de.admadic.papers.reflection.log.ILogger#info(java.lang.Object)
	 */
	public void info(Object message) {
		loggerDelegate.info(message);
	}

	/**
	 * @return	Returns true, if the debug level is enabled.
	 * @see de.admadic.papers.reflection.log.ILogger#isDebugEnabled()
	 */
	public boolean isDebugEnabled() {
		return loggerDelegate.isDebugEnabled();
	}

	/**
	 * @return	Returns true, if the info level is enabled.
	 * @see de.admadic.papers.reflection.log.ILogger#isInfoEnabled()
	 */
	public boolean isInfoEnabled() {
		return loggerDelegate.isInfoEnabled();
	}

	/**
	 * @return	Returns true, if the trace level is enabled.
	 * @see de.admadic.papers.reflection.log.ILogger#isTraceEnabled()
	 */
	public boolean isTraceEnabled() {
		return loggerDelegate.isTraceEnabled();
	}

	/**
	 * @param message
	 * @param t
	 * @see de.admadic.papers.reflection.log.ILogger#trace(java.lang.Object, java.lang.Throwable)
	 */
	public void trace(Object message, Throwable t) {
		loggerDelegate.trace(message, t);
	}

	/**
	 * @param message
	 * @see de.admadic.papers.reflection.log.ILogger#trace(java.lang.Object)
	 */
	public void trace(Object message) {
		loggerDelegate.trace(message);
	}

	/**
	 * @param message
	 * @param t
	 * @see de.admadic.papers.reflection.log.ILogger#warn(java.lang.Object, java.lang.Throwable)
	 */
	public void warn(Object message, Throwable t) {
		loggerDelegate.warn(message, t);
	}

	/**
	 * @param message
	 * @see de.admadic.papers.reflection.log.ILogger#warn(java.lang.Object)
	 */
	public void warn(Object message) {
		loggerDelegate.warn(message);
	}
}
