/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.ui;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Iterator;

import javax.swing.DefaultComboBoxModel;
import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.ScrollPaneConstants;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

import de.admadic.papers.reflection.inspected.ClassList;

/**
 * Provides a panel for choosing a class from a list or by entering its
 * name. This panel includes an "Inspect" button by which the 
 * <code>InspectPanel</code> is shown in a JFrame.
 * 
 * @author Rainer Schwarze
 */
public class ChooserPanel extends JPanel {
	/** */
	private static final long serialVersionUID = 1L;

	JComboBox classes;
	DefaultComboBoxModel modelClasses;
	JButton inspectBtn;
	DefaultListModel modelAvailableClasses;
	JList availableClasses;
	JScrollPane scrollerAvailableClasses;

	/**
	 * Creates an instance of the chooser panel and initializes its content.
	 */
	public ChooserPanel() {
		super();
		initContent();
	}

	/**
	 * Create the content components of the chooser panel.
	 */
	private void initContent() {
		setLayout(new GridBagLayout());
		GridBagConstraints c = new GridBagConstraints();

		c.ipadx = 5;
		c.ipady = 5;
		c.insets = new Insets(5, 5, 5, 5);

		c.fill = GridBagConstraints.HORIZONTAL;
		classes = new JComboBox();
		c.gridx = 0;
		c.gridy = 0;
		c.weightx = 1.0;
		add(classes, c);

		c.weightx = 0.0;
		c.fill = GridBagConstraints.NONE;
		inspectBtn = new JButton("Inspect");
		c.gridx = 1;
		add(inspectBtn, c);

		c.fill = GridBagConstraints.BOTH;
		c.weightx = 1.0;
		c.weighty = 1.0;
		c.gridy = 1;
		c.gridx = 0;
		c.gridwidth = 2;
		availableClasses = new JList();
		scrollerAvailableClasses = new JScrollPane(
				availableClasses,
				ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
				ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS);
		add(scrollerAvailableClasses, c);

		classes.setEditable(true);
		modelClasses = new DefaultComboBoxModel();
		classes.setModel(modelClasses);

		modelAvailableClasses = new DefaultListModel();
		Iterator<Class<?>> it = ClassList.iterator();
		while (it.hasNext()) {
			modelAvailableClasses.addElement(it.next().getCanonicalName());
		}
		availableClasses.setModel(modelAvailableClasses);
		classes.getEditor().setItem("java.lang.Class");

		availableClasses.getSelectionModel().addListSelectionListener(new ListSelectionListener() {
			public void valueChanged(ListSelectionEvent e) {
				classes.getEditor().setItem(availableClasses.getSelectedValue());
			}
		});
		inspectBtn.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				inspectClass();
			}
		});

		classes.setToolTipText(
				"<html>Enter the name of the class which shall be inspected <br>" +
				"and press <b>Inspect</b>.<br>" +
				"(The name of inspected classes will be added to the <br>" +
				"drop down list of this combo box.)");
		availableClasses.setToolTipText(
				"<html>This is a short list of a few classes which were decided to be interesting.<br>" +
				"Click on one entry to fill the field for the class name with it.");
	}

	/**
	 * This method is called when the inspect button is pressed.
	 */
	protected void inspectClass() {
		String className = (String) classes.getEditor().getItem();
		if (modelClasses.getIndexOf(className)<0) {
			modelClasses.addElement(className);
		}
		JFrame frame = new JFrame("Inspecting " + className);
		frame.getContentPane().add(new InspectPanel(className));
		frame.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
		frame.setSize(500, 500);
		frame.setLocationRelativeTo(null);
		frame.setVisible(true);
	}
}
