/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.ui;

import java.awt.Color;
import java.awt.Component;
import java.util.HashMap;

import javax.swing.JTree;
import javax.swing.tree.DefaultTreeCellRenderer;

import de.admadic.papers.reflection.inspectors.TYPE;

/**
 * Provides a renderer for cells in a JTree. This renderer displays different
 * background color of a node depending on the type of the node's user object.
 * (see also {@link TYPE})
 * 
 * If you want to change the colors for the display, this is where you need to 
 * look at.
 * 
 * @author Rainer Schwarze
 */
public class InspectNodeTreeCellRenderer extends DefaultTreeCellRenderer {
	/** */
	private static final long serialVersionUID = 1L;

	static HashMap<TYPE, Color> colorMap = new HashMap<TYPE, Color>();
	static {
		colorMap.put(TYPE.BUSY, 		Color.decode("0xffffcc"));
		colorMap.put(TYPE.ERROR, 		Color.decode("0xffcccc"));
		colorMap.put(TYPE.UNKNOWN, 		Color.decode("0xeeeeee"));
		colorMap.put(TYPE.OBJECT, 		Color.decode("0xffffff"));
		colorMap.put(TYPE.CLASS, 		Color.decode("0xccffcc"));
		colorMap.put(TYPE.CONSTRUCTOR, 	Color.decode("0xccddff"));
		colorMap.put(TYPE.FIELD, 		Color.decode("0xffccff"));	// ddeeff
		colorMap.put(TYPE.METHOD, 		Color.decode("0xeeddff"));
		colorMap.put(TYPE.PROPERTY, 	Color.decode("0xffffee"));
		colorMap.put(TYPE.TYPE, 		Color.decode("0xcceeff"));
		colorMap.put(TYPE.ANNOTATION, 	Color.decode("0xeeffcc"));
		colorMap.put(TYPE.PACKAGE, 		Color.decode("0xffeecc"));

		// previous color map:
//		colorMap.put(TYPE.BUSY, 		Color.decode("0xaaaaaa"));
//		colorMap.put(TYPE.ERROR, 		Color.decode("0xffcccc"));
//		colorMap.put(TYPE.UNKNOWN, 		Color.decode("0xffffff"));
//		colorMap.put(TYPE.OBJECT, 		Color.decode("0xcccccc"));
//		colorMap.put(TYPE.CLASS, 		Color.decode("0xddffee"));
//		colorMap.put(TYPE.CONSTRUCTOR, 	Color.decode("0xffddbb"));
//		colorMap.put(TYPE.FIELD, 		Color.decode("0xbbeeff"));
//		colorMap.put(TYPE.METHOD, 		Color.decode("0xffffbb"));
//		colorMap.put(TYPE.PROPERTY, 	Color.decode("0xffffff"));
//		colorMap.put(TYPE.TYPE, 		Color.decode("0xaaff99"));
//		colorMap.put(TYPE.ANNOTATION, 	Color.decode("0xff0000"));
//		colorMap.put(TYPE.PACKAGE, 		Color.decode("0xeeffdd"));
	}

	/**
	 * Creates an instance of the tree cell renderer. 
	 */
	public InspectNodeTreeCellRenderer() {
		super();
//		setOpaque(true);
	}

	/**
	 * @param tree
	 * @param value
	 * @param sel
	 * @param expanded
	 * @param leaf
	 * @param row
	 * @param hasFocus
	 * @return	Returns the component for rendering the tree cell.
	 * @see javax.swing.tree.DefaultTreeCellRenderer#getTreeCellRendererComponent(javax.swing.JTree, java.lang.Object, boolean, boolean, boolean, int, boolean)
	 */
	@Override
	public Component getTreeCellRendererComponent(JTree tree, Object value, boolean sel, boolean expanded, boolean leaf, int row, boolean hasFocus) {
		Component comp = super.getTreeCellRendererComponent(
				tree, value, sel, expanded, leaf, row, hasFocus);
		// note that the DefaultTreeCellRenderer works a bit differently than the
		// DefaultTableCellRenderer in that the background color cannot be set 
		// to the component directly.
		InspectTreeNode node = (InspectTreeNode) value;
		TYPE type = node.getInspector().getType();
		Color color = colorMap.get(type);
		setBackgroundNonSelectionColor(color);
		return comp;
	}
}
