/**
 * Copyright (c) 2007 admaDIC GbR. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *    1. Redistributions of source code must retain the above copyright 
 *       notice, this list of conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above 
 *       copyright notice, this list of conditions and the following 
 *       disclaimer in the documentation and/or other materials provided 
 *       with the distribution.
 * 
 *    3. All advertising materials mentioning features or use of this 
 *       software must display the following acknowledgement: 
 * 
 *       This product includes software developed by Rainer Schwarze, admaDIC.
 * 
 *    4. Neither the name Rainer Schwarze, admaDIC nor the names of its 
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 */
package de.admadic.papers.reflection.ui;

import javax.swing.tree.DefaultMutableTreeNode;

import de.admadic.papers.reflection.inspectors.IInspector;

/**
 * Provides a tree node for the inspection tree with additional knowledge
 * about what a node represents.
 * 
 * Note that if you change the kind of display (for instance to a TreeTable)
 * you should change this class and {@link InspectTreeModel}. This should
 * limit the number of changes to the rest of the project a bit.
 * 
 * @author Rainer Schwarze
 */
public class InspectTreeNode extends DefaultMutableTreeNode {
	/** */
	private static final long serialVersionUID = 1L;

	/**
	 * Creates an instance with no user object.
	 */
	public InspectTreeNode() {
		super();
	}

	/**
	 * Creates an instance with the given user object (which always shall be
	 * an instance of <code>IInspector&lt;?&gt;</code>). 
	 * 
	 * @param userObject	An IInspector<?> which will be wrapped by this node.
	 * @param allowsChildren
	 */
	public InspectTreeNode(IInspector<?> userObject, boolean allowsChildren) {
		super(userObject, allowsChildren);
	}

	/**
	 * Creates an instance with the given user object (which always shall be
	 * an instance of <code>IInspector&lt;?&gt;</code>).
	 *  
	 * @param userObject	An IInspector<?> which will be wrapped by this node.
	 */
	public InspectTreeNode(Object userObject) {
		super(userObject);
	}

	/**
	 * Returns whether this node is a leaf or not by asking the 
	 * IInspector user object whether it is expandable.
	 * (The node is a leaf, if and only if the inspector is not expandable.)
	 * 
	 * @return	Returns whether this node is a leaf or not.
	 */
	@Override
	public boolean isLeaf() {
		return !getInspector().isExpandable();
	}

	/**
	 * Returns the IInspector which is "represented" by this node.
	 * (This method calls <code>getUserObject</code> and casts.)
	 * 
	 * @return	Returns the IInspector which is "represented" by this node.
	 */
	public IInspector<?> getInspector() {
		return (IInspector<?>) getUserObject();
	}
}
